
from fisher_py.data import Device, TrayShape
from fisher_py.raw_file_reader import RawFileReaderAdapter


if __name__ == '__main__':
    # Check to see if the RAW file name was supplied as an argument to the program
    filename = "my_file.raw"
    
    # Create the RawFileAccess object for accessing the RAW file
    raw_file = RawFileReaderAdapter.file_factory(filename)
    
    raw_file.select_instrument(Device.MS, 1)
    
    print(f'User labels: {", ".join(raw_file.user_label)}')
    print(raw_file.scan_events)
    print(raw_file)


import enum


class TrayShape(enum.Enum):
    """The auto sampler tray shape."""
    
    """Vials or wells are arranged in a rectangle on the tray"""
    Rectangular = 0
    
    """Vials are arranged in a circle."""
    Circular = 1
    
    """Vials are staggered on odd numbered positions on the tray."""
    StaggeredOdd = 2
    
    """Vials are staggered on even numbered positions on the tray."""
    StaggeredEven = 3
    
    """The layout is unknown."""
    Unknown = 4
    
    """The layout information is invalid. No other tray layout data should be displayed."""
    Invalid = 5



from fisher_py.net_wrapping import NetWrapperBase
from fisher_py.data.tray_shape import TrayShape


class AutoSamplerInformation(NetWrapperBase):
    """
    The AutoSamplerInformation interface.
    """
    
    @property
    def tray_index(self) -> int:
        """Gets or sets the tray index, -1 for 'not recorded'"""
        return self._get_wrapped_object_().TrayIndex
    
    @tray_index.setter
    def tray_index(self, value: int):
        """Gets or sets the tray index, -1 for 'not recorded'"""
        assert type(value) is int
        self._get_wrapped_object_().TrayIndex = value
        
    @property
    def vial_index(self) -> int:
        """Gets or sets the vial index, -1 for 'not recorded'"""
        return self._get_wrapped_object_().VialIndex
    
    @vial_index.setter
    def vial_index(self, value: int):
        """Gets or sets the vial index, -1 for 'not recorded'"""
        assert type(value) is int
        self._get_wrapped_object_().VialIndex = value
        
    @property
    def vials_per_tray(self) -> int:
        """Gets or sets the number of vials (or wells) per tray. -1 for 'not recorded'"""
        return self._get_wrapped_object_().VialsPerTray
    
    @vials_per_tray.setter
    def vials_per_tray(self, value: int):
        """Gets or sets the number of vials (or wells) per tray. -1 for 'not recorded'"""
        assert type(value) is int
        self._get_wrapped_object_().VialsPerTray = value
        
    @property
    def vials_per_tray_x(self) -> int:
        """Gets or sets the number of vials (or wells) per tray, across the tray. -1 for 'not recorded'"""
        return self._get_wrapped_object_().VialsPerTrayX
    
    @vials_per_tray_x.setter
    def vials_per_tray_x(self, value: int):
        """Gets or sets the number of vials (or wells) per tray, across the tray. -1 for 'not recorded'"""
        assert type(value) is int
        self._get_wrapped_object_().VialsPerTrayX = value
        
    @property
    def vials_per_tray_y(self) -> int:
        """Gets or sets the number of vials (or wells) per tray, across the tray. -1 for 'not recorded'"""
        return self._get_wrapped_object_().VialsPerTrayY
    
    @vials_per_tray_y.setter
    def vials_per_tray_y(self, value: int):
        """Gets or sets the number of vials (or wells) per tray, across the tray. -1 for 'not recorded'"""
        assert type(value) is int
        self._get_wrapped_object_().VialsPerTrayY = value
        
    @property
    def tray_shape(self) -> TrayShape:
        """Gets or sets the shape. If this property returns "Invalid", no other values in
        this object contain usable information. Invalid data can occur for older raw
        file formats, before auto sampler data was added.
        """
        return TrayShape(self._get_wrapped_object_().TrayShape)
    
    @tray_shape.setter
    def tray_shape(self, value: TrayShape):
        """Gets or sets the shape. If this property returns "Invalid", no other values in
        this object contain usable information. Invalid data can occur for older raw
        file formats, before auto sampler data was added.
        """
        assert type(value) is TrayShape
        self._get_wrapped_object_().TrayShape = value.value
        
    @property
    def tray_shape_as_string(self) -> int:
        """Gets the tray shape as a string"""
        return self._get_wrapped_object_().TrayShapeAsString
    
    @property
    def tray_name(self) -> int:
        """Gets or sets the tray name."""
        return self._get_wrapped_object_().TrayName
    
    @tray_name.setter
    def tray_name(self, value: str):
        """Gets or sets the tray name."""
        assert type(value) is str
        self._get_wrapped_object_().TrayName = value
    


from fisher_py.data.scan_event import ScanEvent
from fisher_py.net_wrapping import NetWrapperBase


class ScanEvents(NetWrapperBase):
    """
    The ScanEvents interface.
    """

    @property
    def segments(self) -> int:
        """Gets the number segments."""
        return self._get_wrapped_object_().Segments
    
    @property
    def scan_events(self) -> int:
        """Gets the total number of scan events, in all segments"""
        return self._get_wrapped_object_().ScanEvents
    
    def get_event_by_segment(self, segment: int, event_number: int) -> ScanEvent:
        """Get an event, indexed by the segment and event numbers (zero based).

        Args:
            segment (int): The segment.
            event_number (int): The event number.

        Returns:
            ScanEvent: The event.
        """
        assert type(event_number) is int
        assert type(segment) is int
            
        net_type = self._get_wrapped_object_().GetEvent(segment, event_number)
            
        return ScanEvent._get_wrapper_(net_type)
    
    def get_event(self, event_number: int) -> ScanEvent:
        """Get an event, using indexed event number (zero based). This gets events from
        all segments in order, use "ScanEvents" to get the total count of events.

        Args:
            event_number (int): The event number.

        Returns:
            ScanEvent: The event.
        """
        assert type(event_number) is int
            
        net_type = self._get_wrapped_object_().GetEvent(event_number)
            
        return ScanEvent._get_wrapper_(net_type)
    
    def get_event_count(self, segment: int) -> int:
        """Gets the number of events in a specific segment (0 based)

        Args:
            segment (int): The segment number

        Returns:
            int: The number of events in this segment
        """
        assert type(segment) is int
        self._get_wrapped_object_().GetEventCount(segment)
